@@ -1,10 +1,12 @@
 import os
 import configparser
+from functools import cached_property
 
 
 class FigConfig(configparser.SafeConfigParser):
-    ALL_BACKENDS = {'AWS', 'AWS_SQS', 'AZURE', 'GCP', 'WORKSPACEONE', 'CHRONICLE'}
+    ALL_BACKENDS = {'AWS', 'AWS_SQS', 'AZURE', 'GCP', 'WORKSPACEONE', 'CHRONICLE', 'CLOUDTRAIL_LAKE'}
     FALCON_CLOUD_REGIONS = {'us-1', 'us-2', 'eu-1', 'us-gov-1'}
+    SENSOR_RECOGNIZED_CLOUDS = {'AWS', 'Azure', 'GCP', 'unrecognized'}
     ENV_DEFAULTS = [
         ['main', 'backends', 'FIG_BACKENDS'],
         ['main', 'worker_threads', 'FIG_WORKER_THREADS'],
@@ -26,7 +28,9 @@ class FigConfig(configparser.SafeConfigParser):
         ['workspaceone', 'syslog_port', 'SYSLOG_PORT'],
         ['chronicle', 'service_account', 'GOOGLE_SERVICE_ACCOUNT_FILE'],
         ['chronicle', 'customer_id', 'GOOGLE_CUSTOMER_ID'],
-        ['chronicle', 'region', 'CHRONICLE_REGION']
+        ['chronicle', 'region', 'CHRONICLE_REGION'],
+        ['cloudtrail_lake', 'channel_arn', 'CLOUDTRAIL_LAKE_CHANNEL_ARN'],
+        ['cloudtrail_lake', 'region', 'CLOUDTRAIL_LAKE_REGION'],
     ]
 
     def __init__(self):
@@ -49,13 +53,10 @@ class FigConfig(configparser.SafeConfigParser):
                     "Please provide environment variable {} or configuration option {}.{}".format(
                         envvar, section, var)) from err
 
-        if int(self.get('events', 'severity_threshold')) not in range(0, 5):
-            raise Exception('Malformed configuration: expected events.severity_threshold to be in range 0-4')
-        if int(self.get('events', 'older_than_days_threshold')) not in range(0, 10000):
-            raise Exception('Malformed configuration: expected events.older_than_days_threshold to be in range 0-10000')
         if int(self.get('main', 'worker_threads')) not in range(1, 128):
             raise Exception('Malformed configuration: expected main.worker_threads to be in range 1-128')
         self.validate_falcon()
+        self.validate_events()
         self.validate_backends()
 
     def validate_falcon(self):
@@ -66,6 +67,17 @@ class FigConfig(configparser.SafeConfigParser):
                 'Malformed configuration: expected falcon.cloud_region to be in {}'.format(self.FALCON_CLOUD_REGIONS)
             )
 
+    def validate_events(self):
+        if not self.detections_exclude_clouds.issubset(self.SENSOR_RECOGNIZED_CLOUDS):
+            raise Exception(
+                'Malformed configuration: expected events.detections_exclude_clouds to be subset of "{}" got "{}"'.format(
+                    self.SENSOR_RECOGNIZED_CLOUDS, self.detections_exclude_clouds))
+
+        if int(self.get('events', 'severity_threshold')) not in range(0, 5):
+            raise Exception('Malformed configuration: expected events.severity_threshold to be in range 0-4')
+        if int(self.get('events', 'older_than_days_threshold')) not in range(0, 10000):
+            raise Exception('Malformed configuration: expected events.older_than_days_threshold to be in range 0-10000')
+
     def validate_backends(self):
         if not self.backends.issubset(self.ALL_BACKENDS) or len(self.backends) < 1:
             raise Exception(
@@ -93,15 +105,29 @@ class FigConfig(configparser.SafeConfigParser):
                 raise Exception('Malformed Configuration: expected chronicle.region to be non-empty')
             if len(self.get('chronicle', 'customer_id')) == 0:
                 raise Exception('Malformed Configuration: expected chronicle.customer_id to be non-empty')
+        if 'CLOUDTRAIL_LAKE' in self.backends:
+            if len(self.get('cloudtrail_lake', 'channel_arn')) == 0:
+                raise Exception('Malformed Configuration: expected cloudtrail_lake.channel_arn to be non-empty')
+            if len(self.get('cloudtrail_lake', 'region')) == 0:
+                raise Exception('Malformed Configuration: expected cloudtrail_lake.region to be non-empty')
         if 'AZURE' in self.backends:
             if len(self.get('azure', 'workspace_id')) == 0:
                 raise Exception('Malformed Configuration: expected azure.workspace_id to be non-empty')
             if len(self.get('azure', 'primary_key')) == 0:
                 raise Exception('Malformed Configuration: expected azure.primary_key to be non-empty')
+            if self.get('azure', 'arc_autodiscovery') not in ['false', 'true']:
+                raise Exception('Malformed Configuration: expected azure.arc_autodiscovery must be either true or false')
 
-    @property
+    @cached_property
     def backends(self):
         return set(self.get('main', 'backends').split(','))
 
+    @cached_property
+    def detections_exclude_clouds(self):
+        value = self.get('events', 'detections_exclude_clouds')
+        if value == '':
+            return set()
+        return set(value.split(','))
+
 
 config = FigConfig()
